@@ -240,8 +240,6 @@ muffle-cerrors appease-cerrors exit-on-error
 ;   |   |       |-- simple-type-error
 ;   |   |
 ;   |   |-- storage-condition
-;   |   |
-;   |   |-- interrupt-condition
 ;   |
 ;   |-- warning
 ;       |
@@ -355,10 +353,6 @@ muffle-cerrors appease-cerrors exit-on-error
   ; "Virtual memory exhausted"
   (define-condition storage-condition (serious-condition) ())
 
-  ; "User break"
-  (define-condition interrupt-condition (serious-condition) ())
-  ; CLISP specific
-
 ; conditions for which user notification is appropriate
 (define-condition warning () ())
 
@@ -429,7 +423,6 @@ muffle-cerrors appease-cerrors exit-on-error
 (define-condition simple-file-error (simple-error file-error) ())
 (define-condition simple-os-error (simple-error os-error) ())
 (define-condition simple-storage-condition (simple-condition storage-condition) ())
-(define-condition simple-interrupt-condition (simple-condition interrupt-condition) ())
 
 ; Bootstrapping
 (%defclcs
@@ -460,7 +453,6 @@ muffle-cerrors appease-cerrors exit-on-error
      (file-error               . simple-file-error)
      (os-error                 . simple-os-error)
      (storage-condition        . simple-storage-condition)
-     (interrupt-condition      . simple-interrupt-condition)
      (warning                  . simple-warning)
     )
 )
@@ -1573,7 +1565,7 @@ Todo:
 #| ; This works as well, but looks more like a hack.
 (defmacro muffle-cerrors (&body body)
   (let ((old-debugger-hook (gensym)))
-    `(LET* ((,old-debugger-hook *DEBUGGER-HOOK*)
+    `(LET* ((,old-debugger-hook *DEBUGGER-HOOK*) 
             (*DEBUGGER-HOOK*
               #'(LAMBDA (CONDITION DEBUGGER-HOOK)
                   (CONTINUE CONDITION)
@@ -1609,21 +1601,24 @@ Todo:
 
 ; (EXIT-ON-ERROR {form}*) executes the forms, but exits Lisp if a
 ; non-continuable error or a Ctrl-C interrupt occurs.
-(defun exitunconditionally (condition)
-  (terpri *error-output*)
-  (write-string "*** - " *error-output*)
-  (print-condition condition *error-output*)
-  (exit t) ; exit Lisp with error
+(defmacro exit-on-error (&body body)
+  `(LET ((*BREAK-DRIVER* #'BATCHMODE-BREAK-DRIVER))
+     (HANDLER-BIND ((ERROR #'(LAMBDA (CONDITION) (EXITONERROR CONDITION))))
+       ,@body
+   ) )
 )
 (defun exitonerror (condition)
   (unless (find-restart 'CONTINUE condition)
-    (exitunconditionally condition)
+    (terpri *error-output*)
+    (write-string "*** - " *error-output*)
+    (print-condition condition *error-output*)
+    (exit t) ; exit Lisp with error
 ) )
-(defmacro exit-on-error (&body body)
-  `(HANDLER-BIND ((INTERRUPT-CONDITION #'EXITUNCONDITIONALLY)
-                  (SERIOUS-CONDITION #'EXITONERROR))
-     ,@body
-   )
+; Need to bind *break-driver* as well, because Ctrl-C interrupts are
+; most often signalled directly, without passing through ERROR or SIGNAL.
+(defun batchmode-break-driver (continuable &optional (condition nil) (print-it nil))
+  (declare (ignore continuable condition print-it))
+  (exit t)
 )
 
 ; (SYSTEM::BATCHMODE-ERRORS {form}*) executes the forms, but handles errors
