@@ -5,7 +5,6 @@
 ;;; FRANCAIS: Fonctions dépendantes de l'installation
 
 (in-package "LISP")
-(export '(clhs-root *clhs-root-default*))
 (mapcar #'fmakunbound '(short-site-name long-site-name
                         editor-name edit-file editor-tempfile))
 
@@ -60,4 +59,4 @@
 You can set the environment variable `CLHSROOT' or redefine this function
 in ~/.clisprc.  On win32 you can also use the Registry."
   (or (sys::getenv "CLHSROOT") *clhs-root-default*))
-(setq *clhs-root-default* "http://www.lisp.org/HyperSpec/")
+(setq *clhs-root-default* "http://www.lisp.org/HyperSpec")
